==> spip_4.0.4.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_referers' => 'حذف پيوند‌هاي ورودي فقط',
	'bouton_effacer_statistiques' => 'پاك كردن تمام آمارها',

	// C
	'csv' => 'سي.اس.وي',

	// I
	'icone_evolution_visites' => 'نمودار بازديدها <br /> @visites@ بازديد  ',
	'icone_repartition_actuelle' => 'نمايش توزيع كنونى',
	'icone_repartition_visites' => 'نمودار بازديدها',
	'icone_statistiques_visites' => 'آمار بازديد كنندگان',
	'info_affichier_visites_articles_plus_visites' => 'فهرست مقاله هائى كه بيش از ديگر مقاله ها خوانده شدن از ابتدا نشان دهيد',
	'info_comment_lire_tableau' => 'طرز خواندن اين جدول',
	'info_forum_statistiques' => 'آمار بازديد كنند گان',
	'info_popularite_2' => ': محبوبيت سايت',
	'info_popularite_3' => '@popularite@ : محبوبيت سايت @visites@ : بازديد',
	'info_popularite_5' => ': محبوبيت',
	'info_previsions' => 'پيش‌بيني‌ها: ',
	'info_question_vignettes_referer' => 'هنگام مراجعه به آمارها، مي‌توانيد نشاني سايت‌هاي مبداء بازديد‌كنندگان را ببينيد.', # MODIF
	'info_question_vignettes_referer_oui' => 'گيراندازي سايت‌هاي مبداء بازديدكنندگان را نشان دادن',
	'info_visites' => ':بازديد ',
	'info_visites_plus_populaires' => 'نمودار بازديد محبوب ترين مقالات و آخرين مقالات منتشر شده را نمايش دهيد ',
	'info_zoom' => 'زوم',
	'item_gerer_statistiques' => 'مديريت آمارهاي بازديدها',

	// O
	'onglet_origine_visites' => 'مبدأ بازديدها',
	'onglet_repartition_debut' => 'از زمان شروع',
	'onglet_repartition_lang' => 'با زبانهاى',

	// R
	'resume' => 'خلاصه',

	// T
	'texte_admin_effacer_stats' => 'اين فرمان تمام داده‌هاي مرتبط با آمارهاي بازديد‌ها از اين سايت و از جمله محبوبيت نسبي مقالات را پاك مي‌كند.',
	'texte_admin_effacer_toutes_stats' => 'دكمه‌ي اول تمام آمارها را حذف مي‌كند:‌بازديدها، محبويت مقاله‌ها و پيوند‌هاي ورودي.',
	'texte_comment_lire_tableau' => 'رتبه مقاله در رده بندى محبوبيتها در حاشيه صفحه مشخص شده كه نشانگر تعداد بازديدهاى روزانه مقاله ميباشد وتعداد بازديدها از ابتدا با قرار دادن نوك فلش برروى مقاله مشخص خواهد شد',
	'texte_signification' => 'خطوط پر رنگ نمودار وروديها (مجموع زير بخشها) و خطوط روشن نشانگر تعداد بازديدكنندگان هر بخش ميباشد.',
	'titre_evolution_visite' => 'تحول بازديدها',
	'titre_liens_entrants' => 'پيوندهاى ورودى ',
	'titre_page_statistiques' => 'آمار براى هر بخش',
	'titre_page_statistiques_visites' => 'آمار بازديدها',

	// V
	'visites' => 'بازديد',
	'visites_journalieres' => 'تعداد بازديدها طي روز ',
	'visites_mensuelles' => 'تعداد بازديد‌ها طي ماه '
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_referers' => 'حذف پيوند‌هاي ورودي فقط',
	'bouton_effacer_statistiques' => 'پاك كردن تمام آمارها',

	// C
	'csv' => 'سي.اس.وي',

	// I
	'icone_evolution_visites' => 'نمودار بازديدها <br /> @visites@ بازديد  ',
	'icone_repartition_actuelle' => 'نمايش توزيع كنونى',
	'icone_repartition_visites' => 'نمودار بازديدها',
	'icone_statistiques_visites' => 'آمار بازديد كنندگان',
	'info_affichier_visites_articles_plus_visites' => 'فهرست مقاله هائى كه بيش از ديگر مقاله ها خوانده شدن از ابتدا نشان دهيد',
	'info_comment_lire_tableau' => 'طرز خواندن اين جدول',
	'info_forum_statistiques' => 'آمار بازديد كنند گان',
	'info_popularite_2' => ': محبوبيت سايت',
	'info_popularite_3' => '@popularite@ : محبوبيت سايت @visites@ : بازديد',
	'info_popularite_5' => ': محبوبيت',
	'info_previsions' => 'پيش‌بيني‌ها: ',
	'info_question_vignettes_referer' => 'هنگام مراجعه به آمارها، مي‌توانيد نشاني سايت‌هاي مبداء بازديد‌كنندگان را ببينيد.', # MODIF
	'info_question_vignettes_referer_oui' => 'گيراندازي سايت‌هاي مبداء بازديدكنندگان را نشان دادن',
	'info_visites' => ':بازديد ',
	'info_visites_plus_populaires' => 'نمودار بازديد محبوب ترين مقالات و آخرين مقالات منتشر شده را نمايش دهيد ',
	'info_zoom' => 'زوم',
	'item_gerer_statistiques' => 'مديريت آمارهاي بازديدها',

	// O
	'onglet_origine_visites' => 'مبدأ بازديدها',
	'onglet_repartition_debut' => 'از زمان شروع',
	'onglet_repartition_lang' => 'با زبانهاى',

	// R
	'resume' => 'خلاصه',

	// T
	'texte_admin_effacer_stats' => 'اين فرمان تمام داده‌هاي مرتبط با آمارهاي بازديد‌ها از اين سايت و از جمله محبوبيت نسبي مقالات را پاك مي‌كند.',
	'texte_admin_effacer_toutes_stats' => 'دكمه‌ي اول تمام آمارها را حذف مي‌كند:‌بازديدها، محبويت مقاله‌ها و پيوند‌هاي ورودي.',
	'texte_comment_lire_tableau' => 'رتبه مقاله در رده بندى محبوبيتها در حاشيه صفحه مشخص شده كه نشانگر تعداد بازديدهاى روزانه مقاله ميباشد وتعداد بازديدها از ابتدا با قرار دادن نوك فلش برروى مقاله مشخص خواهد شد',
	'texte_signification' => 'خطوط پر رنگ نمودار وروديها (مجموع زير بخشها) و خطوط روشن نشانگر تعداد بازديدكنندگان هر بخش ميباشد.',
	'titre_evolution_visite' => 'تحول بازديدها',
	'titre_liens_entrants' => 'پيوندهاى ورودى ',
	'titre_page_statistiques' => 'آمار براى هر بخش',
	'titre_page_statistiques_visites' => 'آمار بازديدها',

	// V
	'visites' => 'بازديد',
	'visites_journalieres' => 'تعداد بازديدها طي روز ',
	'visites_mensuelles' => 'تعداد بازديد‌ها طي ماه ',
];
